pub struct Diagonalization<RingElement> { /* private fields */ }Implementations
Sourceimpl<RingElement> Diagonalization<RingElement>
impl<RingElement> Diagonalization<RingElement>
Sourceimpl<RingElement> Diagonalization<RingElement>
impl<RingElement> Diagonalization<RingElement>
pub fn list_of_single_bar_basis_vector_index_ledgers( &self, ) -> &Vec<SingleBarBasisVectorIndexLedger>
pub fn bases_encoded_as_rows_of_invertible_matrices( &self, ) -> &Vec<VecOfVec<usize, RingElement>>
Sourceimpl<RingElement> Diagonalization<RingElement>
impl<RingElement> Diagonalization<RingElement>
Sourceimpl<RingElement> Diagonalization<RingElement>
impl<RingElement> Diagonalization<RingElement>
Sourcepub fn number_of_bars(&self) -> usize
pub fn number_of_bars(&self) -> usize
Number of bars in the diagonalization
Sourcepub fn basis_vector_index_for_bar_b_over_vertex_v(
&self,
b: usize,
v: usize,
) -> Option<usize>
pub fn basis_vector_index_for_bar_b_over_vertex_v( &self, b: usize, v: usize, ) -> Option<usize>
Returns the index of the basis vector over vertex v that intersects bar number `b``
Returns None if b ≥ {number of bars} or v lies outside the interval for bar b
Sourcepub fn basis_vector_for_bar_b_over_vertex_v(
&self,
b: usize,
v: usize,
) -> Option<&Vec<(usize, RingElement)>>
pub fn basis_vector_for_bar_b_over_vertex_v( &self, b: usize, v: usize, ) -> Option<&Vec<(usize, RingElement)>>
Returns the the basis vector over vertex v that intersects bar number `b``
Returns None if b ≥ {number of bars} or v lies outside the interval for bar b
Sourcepub fn bases(&self) -> &Vec<VecOfVec<usize, RingElement>>
pub fn bases(&self) -> &Vec<VecOfVec<usize, RingElement>>
The sequence of bases that diagonalize the representation
The sequence is formatted as a & Vec< VecOfVec< usize, RingElement > >
Sourcepub fn bar<'a>(&'a self, i: usize) -> Option<&SingleBarBasisVectorIndexLedger>
pub fn bar<'a>(&'a self, i: usize) -> Option<&SingleBarBasisVectorIndexLedger>
Retuns an object which records every basis vector intersected by bar number i
Returns None if the barcode contains i or fewer bars.
Sourcepub fn bars(&self) -> &Vec<SingleBarBasisVectorIndexLedger>
pub fn bars(&self) -> &Vec<SingleBarBasisVectorIndexLedger>
Returns a reference to the list of bars