pub struct OnlyRowIndicesOutsideCollection<Matrix, RowIndicesToExclude>{ /* private fields */ }Expand description
A matrix oracle whose columns iterate only over entries that have indices outside a given collection.
Implementations
Sourceimpl<Matrix, RowIndicesToExclude> OnlyRowIndicesOutsideCollection<Matrix, RowIndicesToExclude>
impl<Matrix, RowIndicesToExclude> OnlyRowIndicesOutsideCollection<Matrix, RowIndicesToExclude>
Sourcepub fn new(
matrix: Matrix,
row_indices_to_exclude: RowIndicesToExclude,
) -> OnlyRowIndicesOutsideCollection<Matrix, RowIndicesToExclude>
pub fn new( matrix: Matrix, row_indices_to_exclude: RowIndicesToExclude, ) -> OnlyRowIndicesOutsideCollection<Matrix, RowIndicesToExclude>
Create a new OnlyRowIndicesOutsideCollection from a matrix and a collection of column indices.
In order to operate properly, the collection of column indices should implement
the MapHasKeyOrSequenceHasElement
trait.